# `3`

`.gitignore`-aware tree tool written in Python.

Example:

```
3
```

Output:

```
.
├── .gitignore
├── 3
├── LICENSE.md
├── README.md
├── pyproject.toml
├── requirements.txt
└── setup.py
```

## Install

```
pip3 install 3-py
```
